package it.unibas.indovinam2pinco.modello;

import java.io.*;

public class Record {

    private static Record singleton;
    private String nomeFileRecord;
    private boolean nuovoRecord;
    private boolean uguagliato;

    static {
        singleton = new Record();
        String tempDir = System.getProperty("java.io.tmpdir");
        singleton.nomeFileRecord = tempDir + "recordIndovina.txt";
    }

    private Record() {}

    public static Record getInstance() {
        return singleton;
    }

    public void setNomeFileRecord(String nomeFileRecord) {
        this.nomeFileRecord = nomeFileRecord;
    }

    public synchronized int getValoreRecord() {
        int valoreRecord;
        BufferedReader file = null;
        try {
            file = new BufferedReader(new FileReader(this.nomeFileRecord));
            valoreRecord = (new Integer(file.readLine())).intValue();
        } catch (FileNotFoundException f) {
            System.err.println("Errore nella lettura del record: " + f);
            valoreRecord = 101;
        } catch (IOException e) {
            System.out.println("Errore nella lettura del record: " + e);
            valoreRecord = 101;
        } catch (NumberFormatException nfe) {
            valoreRecord = 101;
        } finally {
            try {
                if (file != null) {
                    file.close();
                }
            } catch (IOException ioe) {}
        }
        return valoreRecord;
    }

    public synchronized void setValoreRecord(int valoreRecord) {
        if (valoreRecord < 1 || valoreRecord > 100)
            return;
        PrintWriter file = null;
        try {
            file = new PrintWriter(new BufferedWriter(new FileWriter(this.nomeFileRecord)));
            file.println(valoreRecord + "");
        } catch (IOException e) {
            System.out.println("Impossibile salvare il record: " + e);
        } finally {
            if (file != null) {
                file.close();
            }
        }
    }

    public boolean isNuovoRecord() {
        return nuovoRecord;
    }

    public boolean isUguagliato() {
        return uguagliato;
    }

    public void checkRecord(int tentativi) {
        if (tentativi < 1 || tentativi > 100)
            return;
        this.nuovoRecord = false;
        this.uguagliato = false;
        int valoreRecord = getValoreRecord();
        if (tentativi < valoreRecord) {
            setValoreRecord(tentativi);
            this.nuovoRecord = true;
        } else if (tentativi == valoreRecord) {
            this.uguagliato = true;
        }
    }
}
